import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent, PromiseOrValue } from "./common";
export declare namespace EIP712_Canvas {
    type ActionStruct = {
        address_: PromiseOrValue<string>;
        args: PromiseOrValue<BytesLike>;
        blockhash: PromiseOrValue<string>;
        name: PromiseOrValue<string>;
        timestamp: PromiseOrValue<BigNumberish>;
    };
    type ActionStructOutput = [
        string,
        string,
        string,
        string,
        BigNumber
    ] & {
        address_: string;
        args: string;
        blockhash: string;
        name: string;
        timestamp: BigNumber;
    };
    type ActionMessageStruct = {
        clock: PromiseOrValue<BigNumberish>;
        parents: PromiseOrValue<string>[];
        payload: EIP712_Canvas.ActionStruct;
        topic: PromiseOrValue<string>;
    };
    type ActionMessageStructOutput = [
        BigNumber,
        string[],
        EIP712_Canvas.ActionStructOutput,
        string
    ] & {
        clock: BigNumber;
        parents: string[];
        payload: EIP712_Canvas.ActionStructOutput;
        topic: string;
    };
    type SessionStruct = {
        address_: PromiseOrValue<string>;
        blockhash: PromiseOrValue<string>;
        duration: PromiseOrValue<BigNumberish>;
        publicKey: PromiseOrValue<string>;
        timestamp: PromiseOrValue<BigNumberish>;
    };
    type SessionStructOutput = [
        string,
        string,
        BigNumber,
        string,
        BigNumber
    ] & {
        address_: string;
        blockhash: string;
        duration: BigNumber;
        publicKey: string;
        timestamp: BigNumber;
    };
    type SessionMessageStruct = {
        clock: PromiseOrValue<BigNumberish>;
        parents: PromiseOrValue<string>[];
        payload: EIP712_Canvas.SessionStruct;
        topic: PromiseOrValue<string>;
    };
    type SessionMessageStructOutput = [
        BigNumber,
        string[],
        EIP712_Canvas.SessionStructOutput,
        string
    ] & {
        clock: BigNumber;
        parents: string[];
        payload: EIP712_Canvas.SessionStructOutput;
        topic: string;
    };
}
export interface EIP712_CanvasInterface extends utils.Interface {
    functions: {
        "hashAction((address,bytes,string,string,uint256))": FunctionFragment;
        "hashActionMessage((uint256,string[],(address,bytes,string,string,uint256),string))": FunctionFragment;
        "hashSession((address,string,uint256,string,uint256))": FunctionFragment;
        "hashSessionMessage((uint256,string[],(address,string,uint256,string,uint256),string))": FunctionFragment;
        "recoverAddressFromSession((address,string,uint256,string,uint256),bytes)": FunctionFragment;
        "verifyActionMessage((uint256,string[],(address,bytes,string,string,uint256),string),bytes,address)": FunctionFragment;
        "verifySession((address,string,uint256,string,uint256),bytes,address)": FunctionFragment;
        "verifySessionMessage((uint256,string[],(address,string,uint256,string,uint256),string),bytes,address)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "hashAction" | "hashActionMessage" | "hashSession" | "hashSessionMessage" | "recoverAddressFromSession" | "verifyActionMessage" | "verifySession" | "verifySessionMessage"): FunctionFragment;
    encodeFunctionData(functionFragment: "hashAction", values: [EIP712_Canvas.ActionStruct]): string;
    encodeFunctionData(functionFragment: "hashActionMessage", values: [EIP712_Canvas.ActionMessageStruct]): string;
    encodeFunctionData(functionFragment: "hashSession", values: [EIP712_Canvas.SessionStruct]): string;
    encodeFunctionData(functionFragment: "hashSessionMessage", values: [EIP712_Canvas.SessionMessageStruct]): string;
    encodeFunctionData(functionFragment: "recoverAddressFromSession", values: [EIP712_Canvas.SessionStruct, PromiseOrValue<BytesLike>]): string;
    encodeFunctionData(functionFragment: "verifyActionMessage", values: [
        EIP712_Canvas.ActionMessageStruct,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<string>
    ]): string;
    encodeFunctionData(functionFragment: "verifySession", values: [
        EIP712_Canvas.SessionStruct,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<string>
    ]): string;
    encodeFunctionData(functionFragment: "verifySessionMessage", values: [
        EIP712_Canvas.SessionMessageStruct,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<string>
    ]): string;
    decodeFunctionResult(functionFragment: "hashAction", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "hashActionMessage", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "hashSession", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "hashSessionMessage", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "recoverAddressFromSession", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "verifyActionMessage", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "verifySession", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "verifySessionMessage", data: BytesLike): Result;
    events: {};
}
export interface EIP712_Canvas extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: EIP712_CanvasInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        hashAction(action: EIP712_Canvas.ActionStruct, overrides?: CallOverrides): Promise<[string]>;
        hashActionMessage(actionMessage: EIP712_Canvas.ActionMessageStruct, overrides?: CallOverrides): Promise<[string]>;
        hashSession(session: EIP712_Canvas.SessionStruct, overrides?: CallOverrides): Promise<[string]>;
        hashSessionMessage(sessionMessage: EIP712_Canvas.SessionMessageStruct, overrides?: CallOverrides): Promise<[string]>;
        recoverAddressFromSession(session: EIP712_Canvas.SessionStruct, signature: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<[string]>;
        verifyActionMessage(actionMessage: EIP712_Canvas.ActionMessageStruct, signature: PromiseOrValue<BytesLike>, expectedAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<[boolean]>;
        verifySession(session: EIP712_Canvas.SessionStruct, signature: PromiseOrValue<BytesLike>, expectedAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<[boolean]>;
        verifySessionMessage(sessionMessage: EIP712_Canvas.SessionMessageStruct, signature: PromiseOrValue<BytesLike>, expectedAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<[boolean]>;
    };
    hashAction(action: EIP712_Canvas.ActionStruct, overrides?: CallOverrides): Promise<string>;
    hashActionMessage(actionMessage: EIP712_Canvas.ActionMessageStruct, overrides?: CallOverrides): Promise<string>;
    hashSession(session: EIP712_Canvas.SessionStruct, overrides?: CallOverrides): Promise<string>;
    hashSessionMessage(sessionMessage: EIP712_Canvas.SessionMessageStruct, overrides?: CallOverrides): Promise<string>;
    recoverAddressFromSession(session: EIP712_Canvas.SessionStruct, signature: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<string>;
    verifyActionMessage(actionMessage: EIP712_Canvas.ActionMessageStruct, signature: PromiseOrValue<BytesLike>, expectedAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<boolean>;
    verifySession(session: EIP712_Canvas.SessionStruct, signature: PromiseOrValue<BytesLike>, expectedAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<boolean>;
    verifySessionMessage(sessionMessage: EIP712_Canvas.SessionMessageStruct, signature: PromiseOrValue<BytesLike>, expectedAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<boolean>;
    callStatic: {
        hashAction(action: EIP712_Canvas.ActionStruct, overrides?: CallOverrides): Promise<string>;
        hashActionMessage(actionMessage: EIP712_Canvas.ActionMessageStruct, overrides?: CallOverrides): Promise<string>;
        hashSession(session: EIP712_Canvas.SessionStruct, overrides?: CallOverrides): Promise<string>;
        hashSessionMessage(sessionMessage: EIP712_Canvas.SessionMessageStruct, overrides?: CallOverrides): Promise<string>;
        recoverAddressFromSession(session: EIP712_Canvas.SessionStruct, signature: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<string>;
        verifyActionMessage(actionMessage: EIP712_Canvas.ActionMessageStruct, signature: PromiseOrValue<BytesLike>, expectedAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<boolean>;
        verifySession(session: EIP712_Canvas.SessionStruct, signature: PromiseOrValue<BytesLike>, expectedAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<boolean>;
        verifySessionMessage(sessionMessage: EIP712_Canvas.SessionMessageStruct, signature: PromiseOrValue<BytesLike>, expectedAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<boolean>;
    };
    filters: {};
    estimateGas: {
        hashAction(action: EIP712_Canvas.ActionStruct, overrides?: CallOverrides): Promise<BigNumber>;
        hashActionMessage(actionMessage: EIP712_Canvas.ActionMessageStruct, overrides?: CallOverrides): Promise<BigNumber>;
        hashSession(session: EIP712_Canvas.SessionStruct, overrides?: CallOverrides): Promise<BigNumber>;
        hashSessionMessage(sessionMessage: EIP712_Canvas.SessionMessageStruct, overrides?: CallOverrides): Promise<BigNumber>;
        recoverAddressFromSession(session: EIP712_Canvas.SessionStruct, signature: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<BigNumber>;
        verifyActionMessage(actionMessage: EIP712_Canvas.ActionMessageStruct, signature: PromiseOrValue<BytesLike>, expectedAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        verifySession(session: EIP712_Canvas.SessionStruct, signature: PromiseOrValue<BytesLike>, expectedAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        verifySessionMessage(sessionMessage: EIP712_Canvas.SessionMessageStruct, signature: PromiseOrValue<BytesLike>, expectedAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        hashAction(action: EIP712_Canvas.ActionStruct, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        hashActionMessage(actionMessage: EIP712_Canvas.ActionMessageStruct, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        hashSession(session: EIP712_Canvas.SessionStruct, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        hashSessionMessage(sessionMessage: EIP712_Canvas.SessionMessageStruct, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        recoverAddressFromSession(session: EIP712_Canvas.SessionStruct, signature: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        verifyActionMessage(actionMessage: EIP712_Canvas.ActionMessageStruct, signature: PromiseOrValue<BytesLike>, expectedAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        verifySession(session: EIP712_Canvas.SessionStruct, signature: PromiseOrValue<BytesLike>, expectedAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        verifySessionMessage(sessionMessage: EIP712_Canvas.SessionMessageStruct, signature: PromiseOrValue<BytesLike>, expectedAddress: PromiseOrValue<string>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}
